import React, { FC, MutableRefObject } from "react";
import { PromiseOrNot, TreeHandler, TreeNode } from "./type";
export interface FileTreeProps {
    handlerRef?: MutableRefObject<TreeHandler | null>;
    /**
     * 无数据时展示
     */
    emptyRenderer?: () => React.ReactElement;
    /**
     * 渲染节点
     */
    treeItemRenderer?: (treeNode: TreeNode) => React.ReactNode;
    /**
     * 如果传入onChange，组件变成受控组件
     */
    onChange?: (root?: TreeNode) => void;
    /**
     * 读取目录，返回下一层级目录结构
     */
    onReadDir?: (dirUri: string) => PromiseOrNot<TreeNode[]>;
    /**
     * 重命名节点，失败抛异常
     */
    onRename?: (treeNode: TreeNode, toUri: string) => PromiseOrNot<void>;
    /**
     * 删除文件或目录
     */
    onDelete?: (treeNode: TreeNode) => PromiseOrNot<void>;
    /**
     * 为父节点新增子节点
     */
    onNew?: (parentNode: TreeNode, childNode: TreeNode) => PromiseOrNot<TreeNode>;
    /**
     * 移动节点
     */
    onMove: (treeNode: TreeNode, toNode: TreeNode) => PromiseOrNot<TreeNode[]>;
    /**
     * 构造菜单
     */
    onContextMenu?: (event: React.MouseEvent<HTMLDivElement>, treeNode: TreeNode) => void;
    /**
     * 根节点
     */
    root?: TreeNode;
    /**
     * 子节点缩进尺寸
     */
    indent?: number;
    /**
     *  节点高度，默认30
     */
    rowHeight?: number;
    /**
     * 缩进单位，默认px
     */
    indentUnit?: string;
}
export declare const FileTree: FC<FileTreeProps>;
