import { TreeNode } from "./type";
/**
 * 将树转换成列表
 * @param treeData
 * @returns
 */
export declare function flatTreeData(treeData: TreeNode[]): TreeNode[];
/**
 * 计算层级
 * @param uri
 * @param rootUri
 * @returns
 */
export declare function calcLevel(uri: string, rootUri: string): number;
/**
 * 根据uri获取文件名
 * @param uri
 * @returns
 */
export declare function getFileName(uri: string): string | undefined;
/**
 * 根据uri获取节点路径
 * @param tree
 * @param uri
 * @returns
 */
export declare function locateTreeNode(tree: TreeNode, uri: string): number[] | null;
/**
 * 根据uri查询节点
 * @param tree
 * @param uri
 * @returns
 */
export declare function getNodeByUri(tree: TreeNode, uri: string): TreeNode | null;
/**
 * 获取父节点
 * @param tree
 * @param uri
 * @returns
 */
export declare function getParentNode(tree: TreeNode, uri: string): TreeNode | null;
export declare function isParentUri(curUri: string, parentUri: string): boolean;
/**
 * 更新节点属性，并返回新的树
 * @param tree
 * @param uri
 * @param pairs
 * @returns
 */
export declare function mergeTreeNodeProps(tree: TreeNode, uri: string, pairs: Partial<TreeNode>): TreeNode;
/**
 * 为节点增加子节点
 * @param tree
 * @param parentUri
 * @param node
 * @returns
 */
export declare function addChildTo(tree: TreeNode, parentUri: string, node: TreeNode): TreeNode;
/**
 * 从树中删除某节点
 * @param tree
 * @param uri
 * @returns
 */
export declare function removeNode(tree: TreeNode, uri: string): TreeNode | undefined;
/**
 * 遍历树，生成新的树，叶子节点优先遍历
 * @param tree
 * @param fn
 * @returns
 */
export declare function treeMap(tree: TreeNode, fn: (treeNode: TreeNode) => TreeNode): TreeNode;
